% Aufgabe 2.6.4: dreht einen Vektor um Winkel
%    d = VecDrehung( w, v )
%    w : Drehwinkel im Bogenmaß
%    v : der zu drehende Vektor
function d = VecDrehung( w, v )
    A(1,1) =   cos(w);
    A(1,2) = - sin(w);
    A(2,1) =   sin(w);
    A(2,2) =   cos(w);
    
    d = A * v;
end